def repeat(i, n):
    for _ in range(n): yield i

def do_n(functor, n):
    def do(func): return map(functor, repeat(func, n))
    return do

def call_n(n):
    def call(func): return do_n(lambda c: c(), n)(func)
    return call

def call_n_m(n, m):
    def call(func): return call_n(n)(lambda: [*call_n(m)(func)])
    return call

def map_i(c):
    def do(func): return map(lambda i: [*map(func, i)], c)
    return do

def part(*a, **kw):
    def do(func): return lambda: func(*a, **kw)
    return do

def take_n(n):
    def do(i):
        for _ in range(n): yield next(i)
    return do

def label_i(i):
    idx = int()
    for itm in i: yield (idx := idx + 1, *itm)

def entry(flat_maze):
    (as_i) = iter(flat_maze)
    (maze) = [*call_n(10)(lambda: [*take_n(10)(as_i)])]
    (directions, solution) = call_n(2)(list)
    (visited, correct) = call_n(2)(lambda: [*call_n_m(10, 10)(bool)])
    (start_x, start_y), (end_x, end_y) = (
        start   := [0, 0],
        end     := [9, 9],
    )

    def solve(y, x):
        while (y, x) != (end_y, end_x):
            visited[y][x] = True
            solution.append((y, x))

            def do(*a):
                for func in a:
                    (y_, x_) = func()
                    if 0 <= y_ <= 9 and 0 <= x_ <= 9 and not maze[y_][x_] and not visited[y_][x_]: return (y_, x_)

                solution.pop()
                possible = solution[-1]
                solution.pop()
                return possible

            y, x = do(
                lambda: [y - 1, x    ],
                lambda: [y + 1, x    ],
                lambda: [y    , x - 1],
                lambda: [y    , x + 1],
            )

        solution.append((end_y, end_x))
        return solution

    def directions_l(d):
        for o1, o2 in zip(d, d[1:]):
            o = (
                o1[0] - o2[0],
                o1[1] - o2[1],
            )
            yield {
                (  1,  0 ): 1,
                (  0,  1 ): 2,
                ( -1,  0 ): 3,
                (  0, -1 ): 4,
            }[o]

    return [*directions_l(solve(0, 0))]

def tests():
    cases = [
        [
            0, 1, 0, 0, 0, 1, 0, 0, 0, 1,
            0, 1, 0, 1, 0, 1, 0, 1, 0, 0,
            0, 1, 0, 1, 0, 1, 0, 1, 1, 0,
            0, 1, 0, 1, 0, 1, 0, 1, 0, 0,
            0, 1, 0, 1, 0, 1, 0, 1, 0, 1,
            0, 1, 0, 1, 0, 1, 0, 1, 0, 0,
            0, 1, 0, 1, 0, 1, 0, 1, 1, 0,
            0, 1, 0, 1, 0, 1, 0, 1, 0, 0,
            0, 1, 0, 1, 0, 1, 0, 1, 0, 1,
            0, 0, 0, 1, 0, 0, 0, 1, 0, 0,
        ],
        [
            0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
            0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
            0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
            0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
            0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
            0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
            0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
            0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
            0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
            0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        ],
        [
            0, 1, 0, 0, 0, 0, 0, 0, 1, 0,
            0, 0, 0, 0, 0, 1, 1, 0, 0, 0,
            1, 1, 1, 0, 1, 1, 0, 0, 1, 0,
            0, 1, 1, 0, 0, 0, 1, 0, 0, 1,
            0, 0, 0, 0, 1, 0, 1, 1, 0, 0,
            1, 0, 0, 0, 0, 1, 0, 0, 0, 1,
            0, 0, 1, 1, 1, 0, 1, 0, 1, 0,
            1, 0, 0, 0, 1, 0, 1, 0, 0, 0,
            0, 0, 0, 0, 1, 0, 0, 1, 1, 1,
            1, 0, 1, 0, 0, 0, 0, 0, 0, 0,
        ],
        [
            0, 0, 0, 0, 0, 0, 1, 0, 0, 0,
            0, 0, 1, 0, 1, 0, 0, 0, 1, 0,
            0, 0, 1, 1, 0, 0, 1, 1, 1, 0,
            0, 0, 0, 0, 1, 0, 0, 0, 0, 0,
            0, 1, 0, 0, 1, 0, 1, 0, 0, 0,
            0, 0, 1, 0, 0, 0, 0, 0, 0, 0,
            0, 1, 0, 0, 0, 0, 1, 0, 1, 0,
            0, 0, 0, 1, 0, 0, 0, 1, 0, 0,
            0, 0, 0, 1, 0, 0, 0, 0, 0, 0,
            1, 0, 0, 0, 0, 1, 0, 0, 0, 0,
        ],
    ]

    for case in cases:
        print_maze(case)
        print(entry(case))

def print_maze(maze):
    as_i = iter(maze)
    [*call_n(10)(lambda: print("".join("▓" if cell else "░" for cell in take_n(10)(as_i))))]